@@ -630,7 +630,6 @@ class ComicVineTalker(QObject):
                     for w in col_widths:
                         fmtstr += " {{:{}}}|".format(w + 1)
                     width = sum(col_widths) + len(col_widths) * 2
-                    print("width=", width)
                     table_text = ""
                     counter = 0
                     for row in rows:
@@ -741,14 +740,15 @@ class ComicVineTalker(QObject):
         for d in div_list:
             if 'class' in d.attrs:
                 c = d['class']
-                if ('imgboxart' in c and
-                        'issue-cover' in c and
-                        d.img['src'].startswith("http")
-                   ):
-
-                    covers_found += 1
-                    if covers_found != 1:
+                if 'imgboxart' in c and 'issue-cover' in c:
+                    if d.img['src'].startswith("http"):
+                        covers_found += 1
+                        if covers_found != 1:
                             alt_cover_url_list.append(d.img['src'])
+                    elif d.img['data-src'].startswith("http"):
+                        covers_found += 1
+                        if covers_found != 1:
+                            alt_cover_url_list.append(d.img['data-src'])
 
         return alt_cover_url_list
 
